[![Pypi version](https://img.shields.io/pypi/v/portune.svg)](https://pypi.org/project/portune/)
![example](https://github.com/joknarf/portune/actions/workflows/python-publish.yml/badge.svg)
[![Licence](https://img.shields.io/badge/licence-MIT-blue.svg)](https://shields.io/)
[![](https://pepy.tech/badge/portune)](https://pepy.tech/project/portune)
[![Python versions](https://img.shields.io/badge/python-3.9+-blue.svg)](https://shields.io/)

# portune

Multitreaded port scanner

# features

* parallel check of port availability against servers/ports
* console output result / summary
* html full report / dns domain summary / vlan timeout summary
* mail with html summary / report attachment (mailhost relay)

![portune](https://github.com/user-attachments/assets/497a4c73-fb6c-4a20-b7ea-043949c49ca9)

![image](https://github.com/user-attachments/assets/ddea20d8-485d-44d6-8dcc-e817d396e197)
